package ch.example.hsludemo;

import android.content.pm.PackageManager;
import android.support.v7.app.ActionBarActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.ToggleButton;


public class MainActivity extends ActionBarActivity {

    private boolean on = false;
    private ImageView icon;
    private ToggleButton toggleButton;
    private MenuSelectionStrategy menuSelectionStrategy;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        icon = (ImageView) findViewById(R.id.imageView);
        toggleButton = (ToggleButton) findViewById(R.id.toggleButton);
        toggleButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                on = !on; // toggle
                if (on) {
                    icon.setImageResource(R.mipmap.state_on);
                } else {
                    icon.setImageResource(R.mipmap.state_off);
                }
            }
        });
        on = toggleButton.isChecked();

        initTextFields();
        loadMenuSelectionStrategy();
    }

    private void loadMenuSelectionStrategy() {
        String className = getResources().getString(R.string.strategy_class);
        try {
            menuSelectionStrategy = (MenuSelectionStrategy) Class.forName(className).newInstance();
        } catch (Exception e) {
            Log.e("app", "Could not load strategy", e);
        }
    }

    private void initTextFields() {
        try {
            TextView packageName = (TextView) findViewById(R.id.packageName);
            packageName.setText("App id = "+getPackageName());
            TextView appTitle = (TextView) findViewById(R.id.appTitle);
            appTitle.setText("App name = "+getString(R.string.app_name));
            TextView appVersion = (TextView) findViewById(R.id.appVersion);
            appVersion.setText("App version = "+getPackageManager().getPackageInfo(getPackageName(), 0).versionName);
        } catch (PackageManager.NameNotFoundException e) {
            Log.e("main_activity", "Failed to init text fields", e);
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        boolean handled = menuSelectionStrategy.handleMenuSelection(this, item);
        return handled || super.onOptionsItemSelected(item);
    }
}
